Data on the relative abundance (proportion of total observations) of a variety of animal groups as recorded on a network of transects in NE Gabon. A variety of land use variables are also recorded.
data("gabon_diversity")A data frame with 24 observations on the following 14 variables.
TransectIDIdentifier for each transect
DistanceDistance from the nearest village in Km
HuntCatEstimate of the intensity of hunting
LandUseWhat the land is used for
NumHouseholdsNumber of households in the nearest village
Veg_RichVegetation species richness measured as the number of tree species present in a series of plots along the transect
Veg_CanopyCanopy cover as the percentage of the sky blocked by canpoy in each plot, scored as 1 = 0-25, 2 = 26-50, 3 = 51-75, 4 = 76-100
Veg_UnderstoryUnderstory cover as the percentage of the ground covered, scored as for canopy cover
RA_ApesRelative abundance of apes
RA_BirdsRelative abundance of birds
RA_ElephantRelative abundance of elephants
RA_MonkeysRelative abundance of monkeys
RA_RodentRelative abundance of rodents
RA_UngulateRelative abundance of ungulates
Koerner, S.E., Poulsen, J.R., Blanchard, E.J., Okouyi, J. & Clark, C.J. (2017) Vertebrate community composition and diversity declines along a defaunation gradient radiating from rural villages in Gabon (ed S Cheyne). The Journal of applied ecology, 54, 805-814.
# NOT RUN {
data(gabon_diversity)
## maybe str(gabon_diversity)
# }
Run the code above in your browser using DataLab